pub struct ResolveFlags(/* private fields */);Expand description
RESOLVE_* constants for use with openat2.
Implementations
Sourceimpl ResolveFlags
impl ResolveFlags
Sourcepub const NO_XDEV: ResolveFlags
pub const NO_XDEV: ResolveFlags
RESOLVE_NO_XDEV
Sourcepub const NO_MAGICLINKS: ResolveFlags
pub const NO_MAGICLINKS: ResolveFlags
RESOLVE_NO_MAGICLINKS
Sourcepub const NO_SYMLINKS: ResolveFlags
pub const NO_SYMLINKS: ResolveFlags
RESOLVE_NO_SYMLINKS
Sourcepub const BENEATH: ResolveFlags
pub const BENEATH: ResolveFlags
RESOLVE_BENEATH
Sourcepub const IN_ROOT: ResolveFlags
pub const IN_ROOT: ResolveFlags
RESOLVE_IN_ROOT
Sourcepub const CACHED: ResolveFlags
pub const CACHED: ResolveFlags
RESOLVE_CACHED (since Linux 5.12)
Sourceimpl ResolveFlags
impl ResolveFlags
Sourcepub const fn empty() -> ResolveFlags
pub const fn empty() -> ResolveFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> ResolveFlags
pub const fn all() -> ResolveFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<ResolveFlags>
pub const fn from_bits(bits: u64) -> Option<ResolveFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> ResolveFlags
pub const fn from_bits_truncate(bits: u64) -> ResolveFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> ResolveFlags
pub const fn from_bits_retain(bits: u64) -> ResolveFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<ResolveFlags>
pub fn from_name(name: &str) -> Option<ResolveFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: ResolveFlags) -> bool
pub const fn intersects(&self, other: ResolveFlags) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: ResolveFlags) -> bool
pub const fn contains(&self, other: ResolveFlags) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: ResolveFlags)
pub fn insert(&mut self, other: ResolveFlags)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: ResolveFlags)
pub fn remove(&mut self, other: ResolveFlags)
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: ResolveFlags)
pub fn toggle(&mut self, other: ResolveFlags)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: ResolveFlags, value: bool)
pub fn set(&mut self, other: ResolveFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: ResolveFlags) -> ResolveFlags
pub const fn intersection(self, other: ResolveFlags) -> ResolveFlags
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: ResolveFlags) -> ResolveFlags
pub const fn union(self, other: ResolveFlags) -> ResolveFlags
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: ResolveFlags) -> ResolveFlags
pub const fn difference(self, other: ResolveFlags) -> ResolveFlags
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: ResolveFlags) -> ResolveFlags
pub const fn symmetric_difference(self, other: ResolveFlags) -> ResolveFlags
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> ResolveFlags
pub const fn complement(self) -> ResolveFlags
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl ResolveFlags
impl ResolveFlags
Sourcepub const fn iter(&self) -> Iter<ResolveFlags>
pub const fn iter(&self) -> Iter<ResolveFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ResolveFlags>
pub const fn iter_names(&self) -> IterNames<ResolveFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.