pub struct RwFlags(/* private fields */);Implementations
Sourceimpl ReadWriteFlags
impl ReadWriteFlags
Sourcepub const DSYNC: ReadWriteFlags
pub const DSYNC: ReadWriteFlags
RWF_DSYNC (since Linux 4.7)
Sourcepub const HIPRI: ReadWriteFlags
pub const HIPRI: ReadWriteFlags
RWF_HIPRI (since Linux 4.6)
Sourcepub const SYNC: ReadWriteFlags
pub const SYNC: ReadWriteFlags
RWF_SYNC (since Linux 4.7)
Sourcepub const NOWAIT: ReadWriteFlags
pub const NOWAIT: ReadWriteFlags
RWF_NOWAIT (since Linux 4.14)
Sourcepub const APPEND: ReadWriteFlags
pub const APPEND: ReadWriteFlags
RWF_APPEND (since Linux 4.16)
Sourceimpl ReadWriteFlags
impl ReadWriteFlags
Sourcepub const fn empty() -> ReadWriteFlags
pub const fn empty() -> ReadWriteFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> ReadWriteFlags
pub const fn all() -> ReadWriteFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<ReadWriteFlags>
pub const fn from_bits(bits: u32) -> Option<ReadWriteFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> ReadWriteFlags
pub const fn from_bits_truncate(bits: u32) -> ReadWriteFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> ReadWriteFlags
pub const fn from_bits_retain(bits: u32) -> ReadWriteFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<ReadWriteFlags>
pub fn from_name(name: &str) -> Option<ReadWriteFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: ReadWriteFlags) -> bool
pub const fn intersects(&self, other: ReadWriteFlags) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: ReadWriteFlags) -> bool
pub const fn contains(&self, other: ReadWriteFlags) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: ReadWriteFlags)
pub fn insert(&mut self, other: ReadWriteFlags)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: ReadWriteFlags)
pub fn remove(&mut self, other: ReadWriteFlags)
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: ReadWriteFlags)
pub fn toggle(&mut self, other: ReadWriteFlags)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: ReadWriteFlags, value: bool)
pub fn set(&mut self, other: ReadWriteFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: ReadWriteFlags) -> ReadWriteFlags
pub const fn intersection(self, other: ReadWriteFlags) -> ReadWriteFlags
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: ReadWriteFlags) -> ReadWriteFlags
pub const fn union(self, other: ReadWriteFlags) -> ReadWriteFlags
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: ReadWriteFlags) -> ReadWriteFlags
pub const fn difference(self, other: ReadWriteFlags) -> ReadWriteFlags
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: ReadWriteFlags) -> ReadWriteFlags
pub const fn symmetric_difference(self, other: ReadWriteFlags) -> ReadWriteFlags
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> ReadWriteFlags
pub const fn complement(self) -> ReadWriteFlags
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl ReadWriteFlags
impl ReadWriteFlags
Sourcepub const fn iter(&self) -> Iter<ReadWriteFlags>
pub const fn iter(&self) -> Iter<ReadWriteFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ReadWriteFlags>
pub const fn iter_names(&self) -> IterNames<ReadWriteFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.