pub struct StatxFlags(/* private fields */);Expand description
STATX_* constants for use with statx.
Implementations
Sourceimpl StatxFlags
impl StatxFlags
Sourcepub const TYPE: StatxFlags
pub const TYPE: StatxFlags
STATX_TYPE
Sourcepub const MODE: StatxFlags
pub const MODE: StatxFlags
STATX_MODE
Sourcepub const NLINK: StatxFlags
pub const NLINK: StatxFlags
STATX_NLINK
Sourcepub const UID: StatxFlags
pub const UID: StatxFlags
STATX_UID
Sourcepub const GID: StatxFlags
pub const GID: StatxFlags
STATX_GID
Sourcepub const ATIME: StatxFlags
pub const ATIME: StatxFlags
STATX_ATIME
Sourcepub const MTIME: StatxFlags
pub const MTIME: StatxFlags
STATX_MTIME
Sourcepub const CTIME: StatxFlags
pub const CTIME: StatxFlags
STATX_CTIME
Sourcepub const INO: StatxFlags
pub const INO: StatxFlags
STATX_INO
Sourcepub const SIZE: StatxFlags
pub const SIZE: StatxFlags
STATX_SIZE
Sourcepub const BLOCKS: StatxFlags
pub const BLOCKS: StatxFlags
STATX_BLOCKS
Sourcepub const BASIC_STATS: StatxFlags
pub const BASIC_STATS: StatxFlags
STATX_BASIC_STATS
Sourcepub const BTIME: StatxFlags
pub const BTIME: StatxFlags
STATX_BTIME
Sourcepub const MNT_ID: StatxFlags
pub const MNT_ID: StatxFlags
STATX_MNT_ID (since Linux 5.8)
Sourcepub const DIOALIGN: StatxFlags
pub const DIOALIGN: StatxFlags
STATX_DIOALIGN (since Linux 6.1)
Sourcepub const ALL: StatxFlags
pub const ALL: StatxFlags
STATX_ALL
Sourceimpl StatxFlags
impl StatxFlags
Sourcepub const fn empty() -> StatxFlags
pub const fn empty() -> StatxFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> StatxFlags
pub const fn all() -> StatxFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<StatxFlags>
pub const fn from_bits(bits: u32) -> Option<StatxFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> StatxFlags
pub const fn from_bits_truncate(bits: u32) -> StatxFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> StatxFlags
pub const fn from_bits_retain(bits: u32) -> StatxFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<StatxFlags>
pub fn from_name(name: &str) -> Option<StatxFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: StatxFlags) -> bool
pub const fn intersects(&self, other: StatxFlags) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: StatxFlags) -> bool
pub const fn contains(&self, other: StatxFlags) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: StatxFlags)
pub fn insert(&mut self, other: StatxFlags)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: StatxFlags)
pub fn remove(&mut self, other: StatxFlags)
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: StatxFlags)
pub fn toggle(&mut self, other: StatxFlags)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: StatxFlags, value: bool)
pub fn set(&mut self, other: StatxFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: StatxFlags) -> StatxFlags
pub const fn intersection(self, other: StatxFlags) -> StatxFlags
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: StatxFlags) -> StatxFlags
pub const fn union(self, other: StatxFlags) -> StatxFlags
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: StatxFlags) -> StatxFlags
pub const fn difference(self, other: StatxFlags) -> StatxFlags
The intersection of a source flags value with the complement of a target flags value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: StatxFlags) -> StatxFlags
pub const fn symmetric_difference(self, other: StatxFlags) -> StatxFlags
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> StatxFlags
pub const fn complement(self) -> StatxFlags
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl StatxFlags
impl StatxFlags
Sourcepub const fn iter(&self) -> Iter<StatxFlags>
pub const fn iter(&self) -> Iter<StatxFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<StatxFlags>
pub const fn iter_names(&self) -> IterNames<StatxFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.